"use strict";

var _react = _interopRequireDefault(require("react"));

var _jestDomMocks = require("@shopify/jest-dom-mocks");

var _testUtilities = require("../../test-utilities");

var _Link = require("../Link");

var _Spinner = require("../Spinner");

var _Button = require("./Button");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var defaultProps = {
  children: 'Go to next step'
};
describe('<Button />', function () {
  beforeEach(function () {
    _jestDomMocks.matchMedia.mock();
  });
  afterEach(function () {
    _jestDomMocks.matchMedia.restore();
  });
  describe('`<button />`', function () {
    describe('children', function () {
      it('renders the children into the button', function () {
        var text = 'Go to shipping';
        var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, null, text));
        expect(button).toContainReactText(text);
      });
      it('renders the children into the link', function () {
        var text = 'Go to shipping';
        var linkButton = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, {
          to: "/shipping"
        }, text));
        expect(linkButton).toContainReactText(text);
      });
    });
    describe('onPress()', function () {
      it('is called when button is pressed', function () {
        var onPressSpy = jest.fn();
        var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
          onPress: onPressSpy
        })));
        button.find('button').trigger('onClick');
        expect(onPressSpy).toHaveBeenCalledTimes(1);
      });
    });
  });
  describe('`<UnstyledLink />`', function () {
    it('renders when a url is provided', function () {
      var url = '/shipping';
      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        to: url
      })));
      expect(button).toContainReactComponent(_Link.UnstyledLink, {
        to: url
      });
    });
    it('renders a button when disabled', function () {
      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        disabled: true,
        to: "/shipping"
      })));
      expect(button).not.toContainReactComponent(_Link.UnstyledLink);
      expect(button).toContainReactComponent('button', {
        disabled: true
      });
    });
  });
  describe('submit', function () {
    it('renders a type button when not present', function () {
      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, defaultProps));
      expect(button).toContainReactComponent('button', {
        type: 'button'
      });
    });
    it('renders a type submit when present', function () {
      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        submit: true
      })));
      expect(button).toContainReactComponent('button', {
        type: 'submit'
      });
    });
  });
  describe('loading', function () {
    it('disables button when loading', function () {
      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        loading: true
      })));
      expect(button).toContainReactComponent('button', {
        disabled: true
      });
    });
    it('indicates that the button is getting updated', function () {
      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        loading: true
      })));
      expect(button).toContainReactComponent('button', {
        'aria-busy': true
      });
    });
    it('renders a <Spinner> when loading', function () {
      _jestDomMocks.matchMedia.setMedia(function () {
        return {
          matches: false
        };
      });

      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        loading: true
      })));
      expect(button).toContainReactComponent(_Spinner.Spinner);
    });
    it('renders the accessibleLabel as the Spinner children when provided', function () {
      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        loadingLabel: "Processing",
        loading: true
      })));
      expect(button).toContainReactComponent(_Spinner.Spinner, {
        children: 'Processing'
      });
    });
    it('adds the Spinner class when user does not prefers reduced motion', function () {
      _jestDomMocks.matchMedia.setMedia(function () {
        return {
          matches: false
        };
      });

      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        loadingLabel: "Processing",
        loading: true
      })));
      expect(button).toContainReactComponent('span', {
        className: 'LoadingContent Spinner'
      });
    });
    it('removes the Spinner class when user prefers reduced motion', function () {
      _jestDomMocks.matchMedia.setMedia(function () {
        return {
          matches: true
        };
      });

      var button = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react["default"].createElement(_Button.Button, Object.assign({}, defaultProps, {
        loadingLabel: "Processing",
        loading: true
      })));
      expect(button).not.toContainReactComponent('span', {
        className: 'LoadingContent Spinner'
      });
    });
  });
});