"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Checkbox = Checkbox;
exports.CheckboxControl = CheckboxControl;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _Icon = require("../Icon");

var _VisuallyHidden = require("../VisuallyHidden");

var _HiddenForAccessibility = require("../HiddenForAccessibility");

var _InlineError = require("../InlineError");

var _Theme = require("../Theme");

var _id = require("../../utilities/id");

var _errors = require("../../utilities/errors");

var _Checkbox = _interopRequireDefault(require("./Checkbox.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var createId = (0, _id.createIdCreator)('Checkbox');

function Checkbox(_ref) {
  var explicitId = _ref.id,
      accessibilityLabel = _ref.accessibilityLabel,
      error = _ref.error,
      disabled = _ref.disabled,
      children = _ref.children,
      rest = _objectWithoutProperties(_ref, ["id", "accessibilityLabel", "error", "disabled", "children"]);

  var id = (0, _id.useId)(explicitId, createId);
  var errorMarkup = error ? /*#__PURE__*/_react["default"].createElement("div", {
    className: _Checkbox["default"].Error
  }, /*#__PURE__*/_react["default"].createElement(_InlineError.InlineError, {
    controlID: id
  }, error)) : null;
  var labelClassName = (0, _cssUtilities.classNames)(_Checkbox["default"].Label, disabled && _Checkbox["default"]['Label-isDisabled']);
  return /*#__PURE__*/_react["default"].createElement("div", {
    className: (0, _cssUtilities.classNames)(_Checkbox["default"].Wrapper, Boolean(error) && _Checkbox["default"].hasError)
  }, /*#__PURE__*/_react["default"].createElement(CheckboxControl, Object.assign({
    id: id,
    name: name,
    error: Boolean(error),
    disabled: disabled
  }, rest)), /*#__PURE__*/_react["default"].createElement("label", {
    htmlFor: id,
    className: labelClassName
  }, accessibilityLabel ? /*#__PURE__*/_react["default"].createElement(_react["default"].Fragment, null, /*#__PURE__*/_react["default"].createElement(_VisuallyHidden.VisuallyHidden, null, accessibilityLabel), /*#__PURE__*/_react["default"].createElement(_HiddenForAccessibility.HiddenForAccessibility, null, children)) : children), errorMarkup);
}

function CheckboxControl(_ref2) {
  var id = _ref2.id,
      name = _ref2.name,
      _ref2$value = _ref2.value,
      value = _ref2$value === void 0 ? false : _ref2$value,
      _ref2$checked = _ref2.checked,
      checked = _ref2$checked === void 0 ? value : _ref2$checked,
      disabled = _ref2.disabled,
      _ref2$error = _ref2.error,
      error = _ref2$error === void 0 ? false : _ref2$error,
      _onChange = _ref2.onChange;

  var _useThemeConfiguratio = (0, _Theme.useThemeConfiguration)(),
      _useThemeConfiguratio2 = _useThemeConfiguratio.checkbox,
      _useThemeConfiguratio3 = _useThemeConfiguratio2.background,
      background = _useThemeConfiguratio3 === void 0 ? 'surfaceTertiary' : _useThemeConfiguratio3,
      _useThemeConfiguratio4 = _useThemeConfiguratio2.borderColor,
      borderColor = _useThemeConfiguratio4 === void 0 ? 'base' : _useThemeConfiguratio4;

  var className = (0, _cssUtilities.classNames)(_Checkbox["default"].Input, error && _Checkbox["default"]['Input-hasError'], disabled && _Checkbox["default"]['Input-isDisabled'], _Checkbox["default"][(0, _cssUtilities.variationName)('Input-background', background)], _Checkbox["default"][(0, _cssUtilities.variationName)('Input-borderColor', borderColor)]);
  return /*#__PURE__*/_react["default"].createElement("div", {
    className: _Checkbox["default"].Checkbox
  }, /*#__PURE__*/_react["default"].createElement("input", {
    type: "checkbox",
    id: id,
    name: name,
    checked: checked,
    disabled: disabled,
    onChange: function onChange(_ref3) {
      var currentTarget = _ref3.currentTarget;
      _onChange === null || _onChange === void 0 ? void 0 : _onChange(currentTarget.checked);
    },
    className: className,
    "aria-describedby": error ? (0, _errors.errorId)(id) : undefined,
    "aria-invalid": error
  }), /*#__PURE__*/_react["default"].createElement("div", {
    className: _Checkbox["default"].Icon
  }, /*#__PURE__*/_react["default"].createElement(_Icon.Icon, {
    source: "checkmark",
    size: "small"
  })));
}