function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { if (typeof Symbol === "undefined" || !(Symbol.iterator in Object(arr))) return; var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React, { useState, useRef, useEffect, useCallback } from 'react';
import { classNames } from '@shopify/css-utilities';
import { BlockStack } from '../BlockStack';
import { Field } from '../TextField';
import { Labelled } from '../Labelled';
import { useThemeConfiguration } from '../Theme';
import { Popper } from '../Popper';
import { Icon } from '../Icon';
import { InlineError } from '../InlineError';
import { isEmptyString } from '../../utilities/strings';
import { isFocused } from '../../utilities/focus';
import styles from './Autocomplete.css';
export function Autocomplete(_ref) {
  var error = _ref.error,
      id = _ref.id,
      label = _ref.label,
      name = _ref.name,
      onChange = _ref.onChange,
      options = _ref.options,
      onSelectOption = _ref.onSelectOption,
      value = _ref.value,
      ariaLabel = _ref.ariaLabel,
      title = _ref.title,
      children = _ref.children;

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      open = _useState2[0],
      setOpen = _useState2[1];

  var _useState3 = useState(0),
      _useState4 = _slicedToArray(_useState3, 2),
      selected = _useState4[0],
      setSelected = _useState4[1];

  var fieldRef = useRef(null);
  var popperRef = useRef(null);
  var closeButtonRef = useRef(null);

  var _useThemeConfiguratio = useThemeConfiguration(),
      _useThemeConfiguratio2 = _useThemeConfiguratio.textFields,
      labelPosition = _useThemeConfiguratio2.labelPosition,
      _useThemeConfiguratio3 = _useThemeConfiguratio2.background,
      background = _useThemeConfiguratio3 === void 0 ? 'surfaceTertiary' : _useThemeConfiguratio3;

  var errorMarkup = error && /*#__PURE__*/React.createElement(InlineError, {
    controlID: id
  }, error);

  var handleOpen = function handleOpen() {
    if (open) {
      return;
    } // Prevents opening the autocomplete when the address field is filled
    // via browser autofill.


    if (fieldRef.current == null || !isFocused(fieldRef.current)) return;
    setOpen(true);
  };

  var handleClose = useCallback(function () {
    if (!open) {
      return;
    }

    setOpen(false);
  }, [open]);

  var handleChange = function handleChange(newValue) {
    if (newValue === '') {
      handleClose();
    } else {
      handleOpen();
    }

    if (onChange) {
      onChange(newValue);
    }
  };

  var handleOptionMouseOver = function handleOptionMouseOver(index) {
    setSelected(index);
  };

  var handleOptionMouseDown = function handleOptionMouseDown(index) {
    handleClose();

    if (onSelectOption) {
      onSelectOption(options[index]);
    }
  };

  var changeSelectedOption = function changeSelectedOption(diff) {
    if (!open) {
      return;
    }

    setSelected(function (selected) {
      if (selected + diff >= options.length) {
        return 0;
      } else if (selected + diff < 0) {
        return options.length - 1;
      }

      return selected + diff;
    });
  };

  var handleKeyDown = function handleKeyDown(event) {
    switch (event.key) {
      case 'ArrowDown':
        // Prevent cursor move
        event.preventDefault();
        changeSelectedOption(1);
        handleOpen();
        break;

      case 'ArrowUp':
        // Prevent cursor move
        event.preventDefault();
        changeSelectedOption(-1);
        handleOpen();
        break;

      case 'Enter':
        // Prevent form validation
        event.preventDefault();
        handleClose();

        if (onSelectOption) {
          onSelectOption(options[selected]);
        }

        break;

      case 'Escape':
        if (open) {
          handleClose();
        }

        break;

      case 'Tab':
        if (event.shiftKey) {
          handleClose();
        } else if (closeButtonRef.current) {
          closeButtonRef.current.focus();
          event.preventDefault();
        }

        break;
    }
  };

  var autocompleteOptions = React.Children.map(children, function (child) {
    if ( /*#__PURE__*/React.isValidElement(child) && child.type === AutocompleteOptions) {
      return /*#__PURE__*/React.cloneElement(child, {
        id: "".concat(id, "-options")
      }, React.Children.toArray(child.props.children).map(function (child, index) {
        if (_typeof(child) === 'object' && 'type' in child && child.type === AutocompleteOption) {
          return /*#__PURE__*/React.cloneElement(child, {
            id: "".concat(id, "-option-").concat(index),
            isSelected: selected === index,
            onMouseDown: function onMouseDown() {
              var _fieldRef$current;

              handleOptionMouseDown(index);
              (_fieldRef$current = fieldRef.current) === null || _fieldRef$current === void 0 ? void 0 : _fieldRef$current.focus();
            },
            onMouseOver: function onMouseOver() {
              return handleOptionMouseOver(index);
            }
          });
        }
      }));
    }
  });
  useEffect(function () {
    var handleClickOutside = function handleClickOutside(event) {
      var _fieldRef$current2, _popperRef$current;

      if (event.target instanceof Node && !((_fieldRef$current2 = fieldRef.current) === null || _fieldRef$current2 === void 0 ? void 0 : _fieldRef$current2.contains(event.target)) && !((_popperRef$current = popperRef.current) === null || _popperRef$current === void 0 ? void 0 : _popperRef$current.contains(event.target))) {
        handleClose();
      } else if (event.target !== fieldRef.current) {
        var _fieldRef$current3;

        (_fieldRef$current3 = fieldRef.current) === null || _fieldRef$current3 === void 0 ? void 0 : _fieldRef$current3.focus();
      }
    };

    document.addEventListener('click', handleClickOutside);
    return function () {
      document.removeEventListener('click', handleClickOutside);
    };
  }, [handleClose]);
  var autocompleteFooter = React.Children.map(children, function (child) {
    if ( /*#__PURE__*/React.isValidElement(child) && child.type === AutocompleteFooter) {
      return child;
    }
  });
  var fieldFocused = Boolean(fieldRef.current && isFocused(fieldRef.current));
  var closeButtonFocused = Boolean(closeButtonRef.current && isFocused(closeButtonRef.current));
  var renderPopper = open && options.length > 0 && (fieldFocused || closeButtonFocused);
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(BlockStack, {
    spacing: "tight"
  }, /*#__PURE__*/React.createElement(Labelled, {
    label: label,
    htmlFor: id,
    isEmpty: isEmptyString(value),
    position: labelPosition,
    background: background
  }, /*#__PURE__*/React.createElement(Field, {
    ariaActiveDescendant: open ? "".concat(id, "-option-").concat(selected) : undefined,
    ariaAutocomplete: "list",
    ariaControls: "".concat(id, "-options"),
    ariaExpanded: renderPopper,
    autocomplete: !open,
    error: error,
    id: id,
    label: label,
    name: name,
    onInput: handleChange,
    onFocus: handleOpen,
    onKeyDown: handleKeyDown,
    ref: fieldRef,
    role: "combobox",
    value: value
  })), errorMarkup), renderPopper && /*#__PURE__*/React.createElement(Popper, {
    activator: fieldRef.current,
    sameWidth: true,
    placement: "bottom"
  }, /*#__PURE__*/React.createElement("div", {
    className: styles.Autocomplete,
    ref: popperRef
  }, /*#__PURE__*/React.createElement("div", {
    className: styles.Header
  }, /*#__PURE__*/React.createElement("h3", {
    className: styles.Title
  }, title), /*#__PURE__*/React.createElement("button", {
    type: "button",
    className: styles.Close,
    onClick: function onClick() {
      var _fieldRef$current4;

      handleClose();
      (_fieldRef$current4 = fieldRef.current) === null || _fieldRef$current4 === void 0 ? void 0 : _fieldRef$current4.focus();
    },
    onKeyDown: function onKeyDown(event) {
      if (event.key === 'Tab') {
        if (event.shiftKey) {
          var _fieldRef$current5;

          (_fieldRef$current5 = fieldRef.current) === null || _fieldRef$current5 === void 0 ? void 0 : _fieldRef$current5.focus();
          event.preventDefault();
        } else {
          var _fieldRef$current6;

          handleClose();
          (_fieldRef$current6 = fieldRef.current) === null || _fieldRef$current6 === void 0 ? void 0 : _fieldRef$current6.focus();
        }
      }
    },
    ref: closeButtonRef
  }, /*#__PURE__*/React.createElement(Icon, {
    size: "default",
    source: "close",
    color: "subdued",
    accessibilityLabel: ariaLabel
  }))), autocompleteOptions, autocompleteFooter)));
}
export function AutocompleteOptions(_ref2) {
  var children = _ref2.children,
      id = _ref2.id;
  return /*#__PURE__*/React.createElement("ul", {
    className: styles.Options,
    id: id,
    onMouseDown: function onMouseDown(event) {
      // Prevent blur
      event.preventDefault();
    } // eslint-disable-next-line jsx-a11y/no-noninteractive-element-to-interactive-role
    ,
    role: "listbox"
  }, children);
}
export function AutocompleteOption(_ref3) {
  var children = _ref3.children,
      id = _ref3.id,
      isSelected = _ref3.isSelected,
      onMouseDown = _ref3.onMouseDown,
      onMouseOver = _ref3.onMouseOver;
  return (
    /*#__PURE__*/
    // eslint-disable-next-line jsx-a11y/mouse-events-have-key-events
    React.createElement("li", {
      "aria-selected": isSelected,
      className: classNames(styles.Option, _defineProperty({}, styles.selected, isSelected)),
      id: id,
      onMouseDown: onMouseDown,
      onMouseOver: onMouseOver // eslint-disable-next-line jsx-a11y/no-noninteractive-element-to-interactive-role
      ,
      role: "option"
    }, children)
  );
}
export function AutocompleteFooter(_ref4) {
  var children = _ref4.children;
  return /*#__PURE__*/React.createElement("div", {
    className: styles.Footer
  }, children);
}