import React from 'react';
import { mount } from '@quilted/react-testing/dom';
import { Text } from './Text';
describe('<Text />', function () {
  describe('children', function () {
    it('renders the children', function () {
      var content = 'Snowdevil';
      var text = mount( /*#__PURE__*/React.createElement(Text, null, content));
      expect(text).toContainReactText(content);
    });
    it('renders a <span> tag by default', function () {
      var content = 'Snowdevil';
      var text = mount( /*#__PURE__*/React.createElement(Text, null, content));
      expect(text).toContainReactComponent('span');
    });
  });
  describe('emphasized', function () {
    it('renders a <strong>', function () {
      var content = 'Snowdevil';
      var text = mount( /*#__PURE__*/React.createElement(Text, {
        emphasized: true
      }, content));
      expect(text).toContainReactComponent('strong');
    });
  });
  describe('role', function () {
    it('renders an <address> tag when role is "address"', function () {
      var content = 'Snowdevil';
      var text = mount( /*#__PURE__*/React.createElement(Text, {
        role: "address"
      }, content));
      expect(text).toContainReactComponent('address');
    });
    it('renders a <del> tag when role is "deletion"', function () {
      var children = 'Snowdevil';
      var text = mount( /*#__PURE__*/React.createElement(Text, {
        role: "deletion"
      }, children));
      expect(text).toContainReactComponent('del', {
        children: children
      });
    });
    it('renders an <abbr> tag when role type is "abbr"', function () {
      var children = 'GMV';
      var title = 'Gross Merchandise Volume';
      var text = mount( /*#__PURE__*/React.createElement(Text, {
        role: {
          type: 'abbreviation',
          "for": title
        }
      }, children));
      expect(text).toContainReactComponent('abbr', {
        children: children,
        title: title
      });
    });
    it('renders a <bdo> tag when role type is "directional-override"', function () {
      var children = 'info@shopify.com';
      var dir = 'ltr';
      var text = mount( /*#__PURE__*/React.createElement(Text, {
        role: {
          type: 'directional-override',
          direction: dir
        }
      }, children));
      expect(text).toContainReactComponent('bdo', {
        children: children,
        dir: dir
      });
    });
    it('renders a <time> tag when role type is "datetime"', function () {
      var children = 'May 20th, 2020';
      var dateTime = '2020-05-20';
      var text = mount( /*#__PURE__*/React.createElement(Text, {
        role: {
          type: 'datetime',
          machineReadable: dateTime
        }
      }, children));
      expect(text).toContainReactComponent('time', {
        children: children,
        dateTime: dateTime
      });
    });
  });
});