"use strict";

var _react = _interopRequireDefault(require("react"));

var _testUtilities = require("../../test-utilities");

var _Icon = require("../Icon");

var _Button = require("../Button");

var _Banner = require("./Banner");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultProps = {
  title: 'There was an error'
};
describe('<Banner />', () => {
  describe('title', () => {
    it('render its children', () => {
      const title = 'There was an error.';
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, {
        title: title
      }));
      expect(banner).toContainReactText(title);
    });
  });
  describe('status', () => {
    it('renders the right <Icon />', () => {
      const status = 'critical';
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, Object.assign({}, defaultProps, {
        status: status
      })));
      expect(banner).toContainReactComponent(_Icon.Icon, {
        source: status
      });
    });
  });
  describe('collapsible', () => {
    it('renders a collapsible button if collapsible', () => {
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, Object.assign({}, defaultProps, {
        collapsible: true
      })));
      expect(banner).toContainReactComponent(_Button.Button, {
        plain: true
      });
    });
    it('displays chevronDown collapsible button icon by default', () => {
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, Object.assign({}, defaultProps, {
        collapsible: true
      })));
      expect(banner).toContainReactComponent(_Icon.Icon, {
        source: 'chevronDown'
      });
    });
    it('displays chevronUp collapsible button icon on press', () => {
      var _banner$find;

      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, Object.assign({}, defaultProps, {
        collapsible: true
      })));
      (_banner$find = banner.find(_Button.Button)) === null || _banner$find === void 0 ? void 0 : _banner$find.trigger('onPress');
      expect(banner).toContainReactComponent(_Icon.Icon, {
        source: 'chevronUp'
      });
    });
    it('hides the children by default', () => {
      function Child() {
        return /*#__PURE__*/_react.default.createElement("div", null);
      }

      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, Object.assign({}, defaultProps, {
        collapsible: true
      }), /*#__PURE__*/_react.default.createElement(Child, null)));
      expect(banner).not.toContainReactComponent(Child);
    });
    it('displays the children on press', () => {
      var _banner$find2;

      function Child() {
        return /*#__PURE__*/_react.default.createElement("div", null);
      }

      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, Object.assign({}, defaultProps, {
        collapsible: true
      }), /*#__PURE__*/_react.default.createElement(Child, null)));
      (_banner$find2 = banner.find(_Button.Button)) === null || _banner$find2 === void 0 ? void 0 : _banner$find2.trigger('onPress');
      expect(banner).toContainReactComponent(Child);
    });
  });
  describe('iconHidden', () => {
    it('renders the <Icon /> by default', () => {
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, defaultProps));
      expect(banner).toContainReactComponent(_Icon.Icon);
    });
    it('does not renders the <Icon /> when iconHidden is set', () => {
      const banner = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Banner.Banner, Object.assign({}, defaultProps, {
        iconHidden: true
      })));
      expect(banner).not.toContainReactComponent(_Icon.Icon);
    });
  });
});