"use strict";

var _react = _interopRequireDefault(require("react"));

var _faker = _interopRequireDefault(require("faker"));

var _testUtilities = require("../../test-utilities");

var _Icon = require("../Icon");

var _Text = require("../Text");

var _Link = require("../Link");

var _Theme = require("../Theme");

var _Breadcrumbs = require("./Breadcrumbs");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<Breadcrumbs />', () => {
  it('does not render a separator after the final breadcrumb', () => {
    const baseBreadcrumbs = [{
      id: _faker.default.random.uuid(),
      to: _faker.default.internet.url(),
      content: _faker.default.random.word()
    }, {
      id: _faker.default.random.uuid(),
      to: _faker.default.internet.url(),
      content: _faker.default.random.word()
    }];
    const breadcrumbs = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Breadcrumbs.Breadcrumbs, {
      breadcrumbs: baseBreadcrumbs
    }));
    const [firstBreadcrumb, finalBreadcrumb] = breadcrumbs.findAll('li');
    expect(firstBreadcrumb).toContainReactComponent(_Icon.Icon, {
      source: 'chevronRight'
    });
    expect(finalBreadcrumb).not.toContainReactComponent(_Icon.Icon, {
      source: 'chevronRight'
    });
  });
  it('renders a Link for breadcrumbs that are neither active nor disabled', () => {
    const to = _faker.default.internet.url();

    const content = _faker.default.random.word();

    const withDefaultBreadcrumb = [{
      id: _faker.default.random.uuid(),
      to,
      content
    }];
    const breadcrumbs = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Breadcrumbs.Breadcrumbs, {
      breadcrumbs: withDefaultBreadcrumb
    }));
    const [defaultBreadcrumb] = breadcrumbs.findAll('li');
    expect(defaultBreadcrumb).toContainReactComponent(_Link.Link, {
      to
    });
    expect(defaultBreadcrumb).toContainReactText(content);
  });
  it('does not render a Link and sets the aria-current for active breadcrumb', () => {
    const id = _faker.default.random.uuid();

    const content = _faker.default.random.word();

    const withActiveBreadcrumb = [{
      id,
      to: _faker.default.internet.url(),
      content
    }];
    const wrapper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Breadcrumbs.Breadcrumbs, {
      active: id,
      breadcrumbs: withActiveBreadcrumb
    }));
    const [activeBreadcrumb] = wrapper.findAll('li');
    expect(activeBreadcrumb).toContainReactComponent(_Text.Text, {
      children: [null, content],
      emphasized: true
    });
    expect(activeBreadcrumb).toHaveReactProps({
      'aria-current': 'step'
    });
  });
  it('does not render Link if breadcrumb is disabled', () => {
    const content = _faker.default.random.word();

    const withDisabledBreadcrumb = [{
      id: _faker.default.random.uuid(),
      to: _faker.default.internet.url(),
      content,
      disabled: true
    }];
    const wrapper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Breadcrumbs.Breadcrumbs, {
      breadcrumbs: withDisabledBreadcrumb
    }));
    const [disabledBreadcrumb] = wrapper.findAll('li');
    expect(disabledBreadcrumb).toContainReactComponent(_Text.Text, {
      children: [null, content]
    });
  });
  it('emphasizes active breadcrumbs', () => {
    const content = _faker.default.random.word();

    const activeId = _faker.default.random.uuid();

    const withActiveBreadcrumb = [{
      id: activeId,
      to: _faker.default.internet.url(),
      content
    }];
    const wrapper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Breadcrumbs.Breadcrumbs, {
      active: activeId,
      breadcrumbs: withActiveBreadcrumb
    }));
    const [activeBreadcrumb] = wrapper.findAll('li');
    expect(activeBreadcrumb).toContainReactComponent(_Text.Text, {
      emphasized: true,
      children: [null, content]
    });
  });
  it('subdues disabled breadcrumbs', () => {
    const content = _faker.default.random.word();

    const withDisabledBreadcrumb = [{
      id: _faker.default.random.uuid(),
      to: _faker.default.internet.url(),
      content,
      disabled: true
    }];
    const wrapper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Breadcrumbs.Breadcrumbs, {
      breadcrumbs: withDisabledBreadcrumb
    }));
    const [disabledBreadcrumb] = wrapper.findAll('li');
    expect(disabledBreadcrumb).toContainReactComponent(_Text.Text, {
      subdued: true,
      children: [null, content]
    });
  });
  it('numberStyle theme renders a marker', () => {
    const content = _faker.default.random.word();

    const breadcrumbs = [{
      id: _faker.default.random.uuid(),
      to: _faker.default.internet.url(),
      content
    }, {
      id: _faker.default.random.uuid(),
      to: _faker.default.internet.url(),
      content
    }];
    const wrapper = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Breadcrumbs.Breadcrumbs, {
      breadcrumbs: breadcrumbs
    }), {
      theme: (0, _Theme.createTheme)({
        buyerJourney: {
          numberStyle: 'decimalLeadingZero'
        }
      })
    });
    wrapper.findAll('li').forEach((breadcrumb, index) => {
      expect(breadcrumb).toContainReactComponent(_Breadcrumbs.Marker, {
        children: `0${index + 1}`
      });
    });
  });
});