"use strict";

var _react = _interopRequireDefault(require("react"));

var _faker = _interopRequireDefault(require("faker"));

var _testUtilities = require("../../test-utilities");

var _VisuallyHidden = require("../VisuallyHidden");

var _HiddenForAccessibility = require("../HiddenForAccessibility");

var _InlineError = require("../InlineError");

var _Checkbox = require("./Checkbox");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultProps = {
  children: 'Save this information for next time'
};
describe('<Checkbox />', () => {
  it('renders an un-checked checkbox and label', () => {
    const checkbox = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Checkbox.Checkbox, defaultProps));
    expect(checkbox).toContainReactComponent('input', {
      checked: false,
      type: 'checkbox'
    });
    expect(checkbox.find('label')).toContainReactText('Save this information for next time');
  });
  it('renders a checked checkbox when the checked prop is provided and set to true', () => {
    const checkbox = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Checkbox.Checkbox, Object.assign({}, defaultProps, {
      checked: true
    })));
    expect(checkbox).toContainReactComponent('input', {
      checked: true,
      type: 'checkbox'
    });
  });
  it('renders a checked checkbox when the value prop is provided and set to true', () => {
    const checkbox = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Checkbox.Checkbox, Object.assign({}, defaultProps, {
      value: true
    })));
    expect(checkbox).toContainReactComponent('input', {
      checked: true,
      type: 'checkbox'
    });
  });
  it('renders a disabled checkbox when the disabled prop is provided and set to true', () => {
    const checkbox = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Checkbox.Checkbox, Object.assign({}, defaultProps, {
      disabled: true
    })));
    expect(checkbox).toContainReactComponent('input', {
      disabled: true,
      type: 'checkbox'
    });
  });
  it('calls the onChange callback when the checkbox is checked and unchecked', () => {
    const onChangeSpy = jest.fn();
    const checkbox = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Checkbox.Checkbox, Object.assign({}, defaultProps, {
      onChange: onChangeSpy
    })));
    checkbox.find('input').trigger('onChange', {
      currentTarget: {
        checked: true
      }
    });
    expect(onChangeSpy).toHaveBeenCalledWith(true);
    checkbox.find('input').trigger('onChange', {
      currentTarget: {
        checked: false
      }
    });
    expect(onChangeSpy).toHaveBeenCalledWith(false);
  });
  describe('error', () => {
    it('renders an error message when the error prop is provided', () => {
      const error = 'Error message';

      const id = _faker.default.random.alphaNumeric();

      const checkbox = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Checkbox.Checkbox, Object.assign({}, defaultProps, {
        id: id,
        error: error
      })));
      expect(checkbox).toContainReactComponent(_InlineError.InlineError, {
        controlID: id,
        children: error
      });
    });
    it('creates an ID automatically that associates an error with the input', () => {
      var _checkbox$find, _checkbox$find2;

      const error = 'Error message';
      const checkbox = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Checkbox.Checkbox, Object.assign({}, defaultProps, {
        error: error
      })));
      const id = (_checkbox$find = checkbox.find('input')) === null || _checkbox$find === void 0 ? void 0 : _checkbox$find.prop('id');
      expect(id).not.toBeUndefined();
      expect(checkbox).toContainReactComponent(_InlineError.InlineError, {
        controlID: (_checkbox$find2 = checkbox.find('input')) === null || _checkbox$find2 === void 0 ? void 0 : _checkbox$find2.prop('id'),
        children: error
      });
    });
  });
  describe('accessibilityLabel', () => {
    it('renders visually hidden content when the accessibilityLabel is set', () => {
      const accessibilityLabelContent = 'Accessibility content';
      const checkbox = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Checkbox.Checkbox, Object.assign({}, defaultProps, {
        accessibilityLabel: accessibilityLabelContent
      })));
      expect(checkbox.find(_VisuallyHidden.VisuallyHidden)).toContainReactText(accessibilityLabelContent);
    });
    it('hides the label for accessibility purposes when the accessibilityLabel is set', () => {
      const children = 'Basic label';
      const checkbox = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Checkbox.Checkbox, Object.assign({}, defaultProps, {
        accessibilityLabel: "Accessibility content"
      }), children));
      expect(checkbox.find(_HiddenForAccessibility.HiddenForAccessibility)).toContainReactText(children);
    });
  });
});