"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Image = Image;
exports.Media = void 0;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _HiddenForAccessibility = require("../HiddenForAccessibility");

var _Image = _interopRequireDefault(require("./Image.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

let Media;
exports.Media = Media;

(function (Media) {
  Media["Small"] = "(max-width: 600px)";
  Media["Medium"] = "(max-width: 1200px)";
  Media["Large"] = "(min-width: 1201px)";
})(Media || (exports.Media = Media = {}));

const MEDIA_MAP = {
  small: Media.Small,
  medium: Media.Medium,
  large: Media.Large
};

function Image({
  source,
  sources,
  description = '',
  fit,
  bordered,
  loading,
  aspectRatio,
  decorative
}) {
  const initialValue = [];
  const sourcesMarkup = sources && sources.reduce((sourcesProps, {
    source,
    viewportSize,
    resolution
  }) => {
    const media = viewportSize && MEDIA_MAP[viewportSize];
    const maybeSourceProps = sourcesProps.find(({
      media: mediaValue
    }) => media === mediaValue);
    const srcSet = [source, resolution && `${resolution}x`].join(' ').trim();

    if (maybeSourceProps) {
      maybeSourceProps.srcSet += `, ${srcSet}`;
      return sourcesProps;
    } else {
      return [...sourcesProps, {
        media,
        srcSet
      }];
    }
  }, initialValue) // eslint-disable-next-line react/jsx-key
  .map(props => /*#__PURE__*/_react.default.createElement("source", props));
  const className = (0, _cssUtilities.classNames)(_Image.default.Image, bordered && _Image.default.bordered, fit && _Image.default[(0, _cssUtilities.variationName)('fit', fit)]);
  return /*#__PURE__*/_react.default.createElement(MaybeHiddenForA11y, {
    condition: decorative === true
  }, /*#__PURE__*/_react.default.createElement(MaybeAspectRatio, {
    condition: aspectRatio != null,
    aspectRatio: aspectRatio
  }, /*#__PURE__*/_react.default.createElement(MaybePicture, {
    condition: sourcesMarkup != null
  }, sourcesMarkup, /*#__PURE__*/_react.default.createElement("img", {
    src: source,
    alt: description,
    className: className,
    loading: loading
  }))));
}

function MaybeHiddenForA11y({
  children,
  condition
}) {
  return condition ? /*#__PURE__*/_react.default.createElement(_HiddenForAccessibility.HiddenForAccessibility, null, children) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, children);
}

function MaybeAspectRatio({
  children,
  condition,
  aspectRatio
}) {
  return condition ? /*#__PURE__*/_react.default.createElement("div", {
    className: _Image.default.aspectRatio,
    style: {
      paddingBottom: `calc(100% / ${aspectRatio})`
    }
  }, children) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, children);
}

function MaybePicture({
  children,
  condition
}) {
  return condition ? /*#__PURE__*/_react.default.createElement("picture", null, children) : /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, children);
}