"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Labelled = Labelled;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _Text = require("../Text");

var _Truncate = require("../Truncate");

var _Theme = require("../Theme");

var _context = require("./context");

var _Labelled = _interopRequireDefault(require("./Labelled.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function Labelled({
  children,
  label,
  htmlFor,
  isEmpty = true,
  position = 'inside',
  background = 'surfaceTertiary'
}) {
  const [state, dispatch] = (0, _react.useReducer)((state, action) => {
    switch (action.type) {
      case 'focus':
        {
          return { ...state,
            isFocused: true
          };
        }

      case 'blur':
        {
          return { ...state,
            isFloating: !state.isEmpty,
            isFocused: false
          };
        }

      case 'change':
        {
          return { ...state,
            isFloating: true,
            isEmpty: action.isEmpty
          };
        }

      case 'init':
        {
          return { ...state,
            isFloating: !action.isEmpty,
            isEmpty: action.isEmpty
          };
        }
    }
  }, {
    isEmpty,
    isFloating: !isEmpty,
    isFocused: false
  }); // Handle value changes that bypasses the on Change handler
  // ie. asynchronously setting the value for a children

  (0, _react.useEffect)(() => {
    if (!state.isFocused && state.isEmpty !== isEmpty) {
      dispatch({
        type: 'init',
        isEmpty
      });
    } // eslint-disable-next-line react-hooks/exhaustive-deps

  }, [isEmpty]);
  const onFocus = (0, _react.useCallback)(() => dispatch({
    type: 'focus'
  }), []);
  const onBlur = (0, _react.useCallback)(() => dispatch({
    type: 'blur'
  }), []);
  const onChange = (0, _react.useCallback)(isEmpty => dispatch({
    type: 'change',
    isEmpty
  }), []);
  const value = (0, _react.useMemo)(() => ({ ...state,
    onBlur,
    onChange,
    onFocus
  }), [onBlur, onChange, onFocus, state]);
  const {
    label: {
      typographyStyle
    }
  } = (0, _Theme.useThemeConfiguration)();
  return /*#__PURE__*/_react.default.createElement(_context.LabelledContext.Provider, {
    value: value
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _Labelled.default.Wrapper
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)({
      [_Labelled.default.isFloating]: state.isFloating && position === 'inside'
    })
  }, /*#__PURE__*/_react.default.createElement("label", {
    htmlFor: htmlFor,
    className: (0, _cssUtilities.classNames)(_Labelled.default.Label, _Labelled.default[(0, _cssUtilities.variationName)('Label-position', position)], background && _Labelled.default[(0, _cssUtilities.variationName)('Label-onBackground', background)])
  }, /*#__PURE__*/_react.default.createElement(_Text.Text, {
    size: "small",
    subdued: true,
    style: typographyStyle
  }, /*#__PURE__*/_react.default.createElement(_Truncate.Truncate, null, label))), children)));
}