"use strict";

var _react = _interopRequireDefault(require("react"));

var _testUtilities = require("../../test-utilities");

var _Labelled = require("./Labelled");

var _hook = require("./hook");

var _context = require("./context");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const defaultProps = {
  children: /*#__PURE__*/_react.default.createElement("div", null),
  label: '',
  htmlFor: '',
  isEmpty: true
};
describe('<Labelled />', () => {
  it('renders the children', async () => {
    const labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, defaultProps, /*#__PURE__*/_react.default.createElement(Child, null)));
    expect(labelled).toContainReactComponent(Child);
  });
  it('wraps children with a LabelledContext.Provider', async () => {
    const label = 'Email';
    const labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
      label: label
    })));
    expect(labelled).toProvideReactContext(_context.LabelledContext);
  });
  it('hides the floating label if no value is entered', async () => {
    const label = 'Email';
    const labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
      label: label
    })));
    expect(labelled).toProvideReactContext(_context.LabelledContext, expect.objectContaining({
      isFloating: false
    }));
  });
  it('renders a floating label once a value is entered', async () => {
    const label = 'Email';
    const labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
      label: label
    }), /*#__PURE__*/_react.default.createElement(Child, null)));
    labelled.act(() => {
      var _labelled$find;

      (_labelled$find = labelled.find('input')) === null || _labelled$find === void 0 ? void 0 : _labelled$find.trigger('oninput', {
        target: {
          value: 'snowdevil@shopify.com'
        }
      });
    });
    expect(labelled).toProvideReactContext(_context.LabelledContext, expect.objectContaining({
      isFloating: true
    }));
  });
  it('displays a floating label once a value is entered and removed', async () => {
    const label = 'Email';
    const labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
      label: label
    }), /*#__PURE__*/_react.default.createElement(Child, null))); // Enter value

    labelled.act(() => {
      var _labelled$find2;

      (_labelled$find2 = labelled.find('input')) === null || _labelled$find2 === void 0 ? void 0 : _labelled$find2.trigger('oninput', {
        target: {
          value: 'snowdevil@shopify.com'
        }
      });
    }); // Remove value

    labelled.act(() => {
      var _labelled$find3;

      (_labelled$find3 = labelled.find('input')) === null || _labelled$find3 === void 0 ? void 0 : _labelled$find3.trigger('oninput', {
        target: {
          value: ''
        }
      });
    });
    expect(labelled).toProvideReactContext(_context.LabelledContext, expect.objectContaining({
      isFloating: true
    }));
  });
  it('hides a floating label once a value is entered, removed and focus is lost', async () => {
    const label = 'Email';
    const labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
      label: label
    }), /*#__PURE__*/_react.default.createElement(Child, null))); // Enter value

    labelled.act(() => {
      var _labelled$find4;

      (_labelled$find4 = labelled.find('input')) === null || _labelled$find4 === void 0 ? void 0 : _labelled$find4.trigger('oninput', {
        target: {
          value: 'snowdevil@shopify.com'
        }
      });
    }); // Remove value

    labelled.act(() => {
      var _labelled$find5;

      (_labelled$find5 = labelled.find('input')) === null || _labelled$find5 === void 0 ? void 0 : _labelled$find5.trigger('oninput', {
        target: {
          value: ''
        }
      });
    }); // Lose focus

    labelled.act(() => {
      var _labelled$find6;

      (_labelled$find6 = labelled.find('input')) === null || _labelled$find6 === void 0 ? void 0 : _labelled$find6.trigger('onBlur', {
        target: {
          value: ''
        }
      });
    });
    expect(labelled).toProvideReactContext(_context.LabelledContext, expect.objectContaining({
      isFloating: false
    }));
  });
  it('displays a floating label once a value is entered and focus is lost', async () => {
    const label = 'Email';
    const labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, Object.assign({}, defaultProps, {
      label: label
    }), /*#__PURE__*/_react.default.createElement(Child, null))); // Enter value

    labelled.act(() => {
      var _labelled$find7;

      (_labelled$find7 = labelled.find('input')) === null || _labelled$find7 === void 0 ? void 0 : _labelled$find7.trigger('oninput', {
        target: {
          value: 'snowdevil@shopify.com'
        }
      });
    }); // Lose focus

    labelled.act(() => {
      var _labelled$find8;

      (_labelled$find8 = labelled.find('input')) === null || _labelled$find8 === void 0 ? void 0 : _labelled$find8.trigger('onBlur', {
        target: {
          value: ''
        }
      });
    });
    expect(labelled).toProvideReactContext(_context.LabelledContext, expect.objectContaining({
      isFloating: true
    }));
  }); // eslint-disable-next-line jest/no-disabled-tests

  it.skip('displays a floating label if the field is initially empty but its value gets updated', async () => {
    const asynchValue = '150 Elgin';
    const labelled = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, defaultProps, /*#__PURE__*/_react.default.createElement(Child, {
      value: ""
    }))); // TODO - Failing test, review how we want to test children with async values. Recent Preact changes skip setProperty for children and key props
    // might be the culprit of this specific behaviour. https://github.com/preactjs/preact/pull/2213

    labelled.act(() => {
      labelled.setProps({
        isEmpty: false,
        children: /*#__PURE__*/_react.default.createElement(Child, {
          value: asynchValue
        })
      });
    });
    expect(labelled).toContainReactComponent('input', {
      value: asynchValue
    });
    expect(labelled).toProvideReactContext(_context.LabelledContext, expect.objectContaining({
      isFloating: true
    }));
  });
});

function Child({
  value
}) {
  const {
    onBlur,
    onChange,
    onFocus
  } = (0, _hook.useLabelled)();
  return /*#__PURE__*/_react.default.createElement("input", {
    value: value,
    onBlur: onBlur,
    onChange: ({
      target
    }) => {
      onChange(!target.value || target.value === '');
    },
    onFocus: onFocus
  });
}