"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Layout = Layout;

var _react = _interopRequireDefault(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _units = require("../../utilities/units");

var _id = require("../../utilities/id");

var _Layout = _interopRequireDefault(require("./Layout.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const MEDIAQUERY_MAP = new Map([['small', '@media all and (max-width: 749px)'], ['medium', '@media all and (min-width: 750px) and (max-width: 1199px)'], ['large', '@media all and (min-width: 1200px)']]);
const createId = (0, _id.createIdCreator)('Layout');

function Layout({
  inlineAlignment,
  blockAlignment,
  maxInlineSize,
  sizes,
  media,
  children
}) {
  const uniqueClassName = createId();
  const CSSSelector = `.${uniqueClassName} > .${_Layout.default.LayoutInner}`;
  const layoutClassName = (0, _cssUtilities.classNames)(_Layout.default.Layout, uniqueClassName, blockAlignment && _Layout.default[(0, _cssUtilities.variationName)('blockAlignment', blockAlignment)], inlineAlignment && _Layout.default[(0, _cssUtilities.variationName)('inlineAlignment', inlineAlignment)]);
  const layoutInnerClassName = (0, _cssUtilities.classNames)(_Layout.default.LayoutInner, inlineAlignment && _Layout.default[(0, _cssUtilities.variationName)('LayoutInner-inlineAlignment', inlineAlignment)]);
  const defaults = {
    viewportSize: 'default',
    sizes,
    maxInlineSize
  };
  const layoutStyles = media ? generateMediaStyles(CSSSelector, [defaults, ...media]) : generateMediaStyles(CSSSelector, [defaults]);
  return /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("style", null, layoutStyles), /*#__PURE__*/_react.default.createElement("div", {
    className: layoutClassName
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: layoutInnerClassName
  }, children)));
}

function generateSizesStyles(selector, sizes) {
  return sizes.reduce((acc, basicSize, index) => {
    const canGrow = basicSize === 'fill';
    const canShrink = typeof basicSize !== 'number';
    const size = typeof basicSize === 'number' ? (0, _units.pixelOrPercent)(basicSize) : 'auto';
    const inlineStyles = `
        ${selector} > :nth-child(${index + 1}) {
          flex: ${canGrow ? '1' : '0'} ${canShrink ? '1' : '0'} ${size};
          max-width: ${size};
        }
      `;
    return [acc, inlineStyles].join(' ');
  }, '');
}

function generateMediaStyles(selector, media) {
  return media.reduce((acc, {
    viewportSize,
    maxInlineSize,
    sizes
  }) => {
    const sizesStyles = sizes && generateSizesStyles(selector, sizes);
    const wrappingStyles = (sizes === null || sizes === void 0 ? void 0 : sizes.includes(1)) ? `${selector} { flex-wrap: wrap; }` : '';
    const maxInlineSizeStyles = maxInlineSize ? `${selector} { max-width: ${(0, _units.pixelOrPercent)(maxInlineSize)}; }` : '';
    const mediaStyles = [sizesStyles, wrappingStyles, maxInlineSizeStyles];
    const inlineStyles = viewportSize === 'default' || typeof MEDIAQUERY_MAP.get(viewportSize) === 'undefined' ? mediaStyles : [MEDIAQUERY_MAP.get(viewportSize), '{', ...mediaStyles, '}'];
    return [acc, ...inlineStyles].join(' ');
  }, '');
}