"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Modal = Modal;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _Portal = require("../Portal");

var _Heading = require("../Heading");

var _Icon = require("../Icon");

var _transition = require("../../utilities/transition");

var _Modal = _interopRequireDefault(require("./Modal.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const IFRAME_LOADING_HEIGHT = 200;
const DEFAULT_IFRAME_CONTENT_HEIGHT = 400;

function isIFrameProps(props) {
  return props.src !== undefined;
}

function Modal({
  open: openProp = false,
  title,
  height,
  onClose,
  ...props
}) {
  const iFrameTitle = 'body markup';
  const [open, setOpen] = (0, _react.useState)(openProp);
  const [iframeHeight, setIframeHeight] = (0, _react.useState)(IFRAME_LOADING_HEIGHT);
  const titleBarRef = (0, _react.useRef)(null);
  const transition = (0, _transition.useTransition)(open, {
    enter: 'fast'
  });

  const transitionClassName = _Modal.default[(0, _cssUtilities.variationName)('transition', transition)];

  const closeModal = (0, _react.useCallback)(() => {
    setOpen(false);
    if (onClose) onClose();
  }, [onClose]);
  const handleKeyDown = (0, _react.useCallback)(event => event.key === 'Escape' && closeModal(), [closeModal]);
  (0, _react.useEffect)(() => {
    if (openProp) {
      setOpen(true);
    } else {
      closeModal();
    }
  }, [openProp, closeModal]);
  (0, _react.useEffect)(() => {
    document.addEventListener('keydown', handleKeyDown, false);
    return () => {
      document.removeEventListener('keydown', handleKeyDown, false);
    };
  }, [handleKeyDown]);
  const handleIFrameLoad = (0, _react.useCallback)(evt => {
    const iframe = evt.target;

    if (iframe && iframe.contentWindow) {
      try {
        setIframeHeight(iframe.contentWindow.document.body.scrollHeight);
      } catch {
        setIframeHeight(DEFAULT_IFRAME_CONTENT_HEIGHT);
      }
    }
  }, []);
  if (!open) return null; // TODO handle focus

  let contentHeight;

  if (height) {
    if (title) {
      var _titleBarRef$current$, _titleBarRef$current;

      contentHeight = `${height - ((_titleBarRef$current$ = (_titleBarRef$current = titleBarRef.current) === null || _titleBarRef$current === void 0 ? void 0 : _titleBarRef$current.clientHeight) !== null && _titleBarRef$current$ !== void 0 ? _titleBarRef$current$ : 64)}px`;
    }

    contentHeight = `${height}px`;
  } else if (isIFrameProps(props)) {
    contentHeight = `${iframeHeight}px`;
  } else {
    contentHeight = 'auto';
  }

  return /*#__PURE__*/_react.default.createElement(_Portal.Portal, null, /*#__PURE__*/_react.default.createElement("div", {
    className: _Modal.default.Wrapper
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_Modal.default.Backdrop, transitionClassName)
  }), /*#__PURE__*/_react.default.createElement("div", {
    className: (0, _cssUtilities.classNames)(_Modal.default.Content, transitionClassName)
  }, title && /*#__PURE__*/_react.default.createElement("header", {
    className: _Modal.default.Header,
    ref: titleBarRef
  }, /*#__PURE__*/_react.default.createElement(_Heading.Heading, {
    level: 1
  }, title), /*#__PURE__*/_react.default.createElement("button", {
    type: "button",
    className: _Modal.default.Button,
    onClick: () => closeModal()
  }, /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    source: "close",
    size: "large"
  }))), isIFrameProps(props) ?
  /*#__PURE__*/
  // eslint-disable-next-line jsx-a11y/no-noninteractive-element-interactions
  _react.default.createElement("iframe", {
    src: props.src,
    name: props.iFrameName,
    onLoad: handleIFrameLoad,
    title: iFrameTitle,
    className: _Modal.default.IFrame,
    style: {
      // stylelint-disable-next-line value-keyword-case
      height: contentHeight
    }
  }) : /*#__PURE__*/_react.default.createElement("div", {
    className: _Modal.default.Body,
    style: {
      // stylelint-disable-next-line value-keyword-case
      height: contentHeight
    }
  }, props.children))));
}