"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Field = exports.TextField = void 0;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _Icon = require("../Icon");

var _VisuallyHidden = require("../VisuallyHidden");

var _Labelled = require("../Labelled");

var _Text = require("../Text");

var _Tooltip = require("../Tooltip");

var _InlineError = require("../InlineError");

var _BlockStack = require("../BlockStack");

var _Theme = require("../Theme");

var _typographyStyles = _interopRequireDefault(require("../../utilities/typography-styles.css"));

var _strings = require("../../utilities/strings");

var _id = require("../../utilities/id");

var _errors = require("../../utilities/errors");

var _autocomplete = require("../../utilities/autocomplete");

var _TextField = _interopRequireDefault(require("./TextField.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const createId = (0, _id.createIdCreator)('TextField');

/**
 * A text field is an input field that merchants can type into.
 */
const TextField = /*#__PURE__*/(0, _react.forwardRef)((props, ref) => {
  const {
    textFields: {
      labelPosition,
      background = 'surfaceTertiary'
    }
  } = (0, _Theme.useThemeConfiguration)();
  const {
    accessibilityDescription,
    error,
    id: explicitId,
    label,
    tooltip,
    value: explicitValue
  } = props;
  const id = (0, _id.useId)(explicitId, createId);
  const descriptionId = accessibilityDescription ? `${id}-description` : undefined;
  const description = descriptionId ? /*#__PURE__*/_react.default.createElement(_VisuallyHidden.VisuallyHidden, null, /*#__PURE__*/_react.default.createElement(_Text.Text, {
    id: descriptionId
  }, accessibilityDescription)) : null;

  const errorMarkup = error && /*#__PURE__*/_react.default.createElement(_InlineError.InlineError, {
    controlID: id
  }, error);

  const tooltipMarkup = tooltip ? /*#__PURE__*/_react.default.createElement("div", {
    className: _TextField.default.Tooltip
  }, /*#__PURE__*/_react.default.createElement(_Tooltip.Tooltip, {
    content: tooltip.content
  }, /*#__PURE__*/_react.default.createElement(_VisuallyHidden.VisuallyHidden, null, tooltip.label), /*#__PURE__*/_react.default.createElement(_Icon.Icon, {
    source: "questionFill",
    size: "large",
    color: "subdued"
  }))) : null;
  return /*#__PURE__*/_react.default.createElement(_BlockStack.BlockStack, {
    spacing: "tight"
  }, /*#__PURE__*/_react.default.createElement(_Labelled.Labelled, {
    label: label,
    htmlFor: id,
    isEmpty: (0, _strings.isEmptyString)(explicitValue),
    position: labelPosition,
    background: background
  }, /*#__PURE__*/_react.default.createElement("div", {
    className: _TextField.default.Wrapper
  }, description, /*#__PURE__*/_react.default.createElement(Field, Object.assign({
    ref: ref
  }, props, {
    id: id,
    ariaDescribedBy: descriptionId
  })), tooltipMarkup)), errorMarkup);
});
exports.TextField = TextField;
const Field = /*#__PURE__*/(0, _react.forwardRef)(({
  id,
  name,
  label,
  value: explicitValue,
  type = 'text',
  role,
  required,
  error,
  tooltip,
  autocomplete,
  autofocus,
  multiline,
  ariaActiveDescendant,
  ariaAutocomplete,
  ariaControls,
  ariaDescribedBy,
  ariaExpanded,
  onFocus,
  onBlur,
  onChange,
  onInput,
  onKeyDown
}, ref) => {
  const innerRef = (0, _react.useRef)();
  const refsSetter = (0, _react.useCallback)(instance => {
    if (typeof ref === 'function') {
      ref(instance);
    } else if (ref) {
      ref.current = instance;
    }

    innerRef.current = instance;
  }, [ref]);
  (0, _react.useEffect)(() => {
    if (autofocus) {
      var _innerRef$current;

      (_innerRef$current = innerRef.current) === null || _innerRef$current === void 0 ? void 0 : _innerRef$current.focus();
    }
  }, [autofocus]);
  const {
    textFields: {
      labelPosition = 'inside',
      background = 'surfaceTertiary',
      border = 'full',
      borderColor = 'base',
      focusBorder = 'full',
      typographyStyle: style
    }
  } = (0, _Theme.useThemeConfiguration)();
  const labelled = (0, _Labelled.useLabelled)();
  const [localValue, setLocalValue] = usePartiallyControlledState(explicitValue);
  const className = (0, _cssUtilities.classNames)(_TextField.default.Field, Boolean(error) && _TextField.default.hasError, Boolean(tooltip) && _TextField.default['Field-hasTooltip'], labelled.isFloating && labelPosition !== 'outside' && _TextField.default['Field-isFloating'], _TextField.default[(0, _cssUtilities.variationName)('Field-background', background)], _TextField.default[(0, _cssUtilities.variationName)('Field-border', border)], _TextField.default[(0, _cssUtilities.variationName)('Field-borderColor', borderColor)], _TextField.default[(0, _cssUtilities.variationName)('Field-focusBorder', focusBorder)], style && _typographyStyles.default[style]);
  const finalDescribedBy = [ariaDescribedBy, error && (0, _errors.errorId)(id)].filter(Boolean).join(' ');

  const field = /*#__PURE__*/_react.default.createElement(multiline ? 'textarea' : 'input', {
    id,
    name,
    placeholder: labelled.isFloating || labelPosition === 'outside' ? undefined : label,
    className,
    required,
    type: normalizeType(multiline ? undefined : type),
    'aria-activedescendant': ariaActiveDescendant,
    'aria-autocomplete': ariaAutocomplete,
    'aria-controls': ariaControls,
    'aria-describedby': finalDescribedBy,
    'aria-expanded': ariaExpanded,
    'aria-invalid': Boolean(error),
    'aria-required': required,
    onBlur: ({
      currentTarget: {
        value
      }
    }) => {
      const currentValue = explicitValue !== null && explicitValue !== void 0 ? explicitValue : '';
      if (value !== currentValue) onChange === null || onChange === void 0 ? void 0 : onChange(value);
      onBlur === null || onBlur === void 0 ? void 0 : onBlur();
      labelled.onBlur();
    },

    onChange({
      currentTarget: {
        value
      }
    }) {
      setLocalValue(value);
      onInput === null || onInput === void 0 ? void 0 : onInput(value);
      labelled.onChange((0, _strings.isEmptyString)(value));
    },

    onFocus: () => {
      onFocus === null || onFocus === void 0 ? void 0 : onFocus();
      labelled.onFocus();
    },
    onKeyDown,
    ref: refsSetter,
    role,
    value: localValue,
    autoComplete: (0, _autocomplete.autocompleteToHtml)(autocomplete),
    autofocus
  });

  return field;
});
exports.Field = Field;

function usePartiallyControlledState(value) {
  const [localValue, setLocalValue] = (0, _react.useState)(value);
  const lastExplicitValue = (0, _react.useRef)(value);
  let valueToReturn = localValue;

  if (lastExplicitValue.current !== value) {
    lastExplicitValue.current = value;
    setLocalValue(value);
    valueToReturn = value;
  }

  return [valueToReturn, setLocalValue];
} // Takes the `type` we allow for a TextField props, and maps it to the
// valid type for an HTML input. Currently, the only difference is
// that we use the full word `telephone` instead of `tel`.


function normalizeType(type) {
  return type === 'telephone' ? 'tel' : type;
}