"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Tooltip = Tooltip;
exports.Arrow = Arrow;
exports.SPACE_KEY_CODE = exports.ESCAPE_KEY_CODE = exports.RETURN_KEY_CODE = void 0;

var _react = _interopRequireWildcard(require("react"));

var _cssUtilities = require("@shopify/css-utilities");

var _id = require("../../utilities/id");

var _transition = require("../../utilities/transition");

var _Popper = require("../Popper");

var _Tooltip = _interopRequireDefault(require("./Tooltip.css"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const RETURN_KEY_CODE = 13;
exports.RETURN_KEY_CODE = RETURN_KEY_CODE;
const ESCAPE_KEY_CODE = 27;
exports.ESCAPE_KEY_CODE = ESCAPE_KEY_CODE;
const SPACE_KEY_CODE = 32;
exports.SPACE_KEY_CODE = SPACE_KEY_CODE;
const createId = (0, _id.createIdCreator)('Tooltip');

function Tooltip({
  content,
  children
}) {
  const [active, setActive] = (0, _react.useState)(false);
  const buttonRef = (0, _react.useRef)(null);
  const transition = (0, _transition.useTransition)(active, {
    exit: 'slow'
  });

  function handleKeyDown(event) {
    switch (event.keyCode) {
      case RETURN_KEY_CODE:
      case SPACE_KEY_CODE:
        event.preventDefault();
        setActive(!active);
        break;

      case ESCAPE_KEY_CODE:
        event.preventDefault();
        setActive(false);
        break;
    }
  }

  function handleClick() {
    setActive(!active);
  }

  const className = (0, _cssUtilities.classNames)(_Tooltip.default.Tooltip, _Tooltip.default[(0, _cssUtilities.variationName)('transition', transition)]);
  const id = (0, _id.useId)(undefined, createId);
  const controlId = active ? id : undefined;
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _Tooltip.default.Wrapper
  }, /*#__PURE__*/_react.default.createElement("button", {
    type: "button",
    className: _Tooltip.default.Button,
    "aria-pressed": active,
    "aria-controls": controlId,
    "aria-describedby": controlId,
    onFocus: () => {
      setActive(true);
    },
    onBlur: () => {
      setActive(false);
    },
    onMouseEnter: () => {
      setActive(true);
    },
    onMouseLeave: () => {
      setActive(false);
    },
    onClick: handleClick,
    onKeyDown: handleKeyDown,
    ref: buttonRef
  }, children), transition !== 'exited' && /*#__PURE__*/_react.default.createElement(_Popper.Popper, {
    activator: buttonRef.current,
    preventOverflow: true
  }, /*#__PURE__*/_react.default.createElement("p", {
    id: controlId,
    role: "tooltip",
    onMouseEnter: () => {
      setActive(true);
    },
    onMouseLeave: () => {
      setActive(false);
    },
    className: className
  }, content, /*#__PURE__*/_react.default.createElement(Arrow, null))));
}

function Arrow() {
  const {
    clipping
  } = (0, _Popper.usePopper)();
  const offsetX = (clipping.right || clipping.left) && `calc(${document.dir === 'ltr' ? '-50' : '50'}% - ${clipping.right || clipping.left}px)`;
  return /*#__PURE__*/_react.default.createElement("div", {
    className: _Tooltip.default.Arrow,
    style: { ...(offsetX && {
        transform: `translateX(${offsetX})`,
        MozTransform: `translateX(${offsetX})`,
        webkitTransform: `translateX(${offsetX})`
      })
    }
  });
}