"use strict";

var _react = _interopRequireDefault(require("react"));

var _dom = require("@quilted/react-testing/dom");

var _testUtilities = require("../../test-utilities");

var _Tooltip = require("./Tooltip");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

jest.useFakeTimers();
const children = 'This is a tooltip';
const defaultProps = {
  content: 'In case we need to contact you about your order'
};
describe('<Tooltip />', () => {
  it('renders the children within a button', () => {
    const tooltip = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Tooltip.Tooltip, defaultProps, children));
    expect(tooltip).toContainReactComponent('button', {
      children
    });
  });
  it('renders the tooltip content when the control is focused', () => {
    var _tooltip$find;

    const tooltip = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Tooltip.Tooltip, defaultProps, children));
    (_tooltip$find = tooltip.find('button')) === null || _tooltip$find === void 0 ? void 0 : _tooltip$find.trigger('onFocus');
    expect(tooltip).toContainReactComponent('p', {
      children: expect.arrayContaining([defaultProps.content])
    });
  });
  it('renders the tooltip arrow when the control is focused', () => {
    var _tooltip$find2;

    const tooltip = (0, _testUtilities.mountWithContext)( /*#__PURE__*/_react.default.createElement(_Tooltip.Tooltip, defaultProps, children));
    (_tooltip$find2 = tooltip.find('button')) === null || _tooltip$find2 === void 0 ? void 0 : _tooltip$find2.trigger('onFocus');
    expect(tooltip).toContainReactComponent(_Tooltip.Arrow);
  });
  it('does not render the tooltip content when the control is blurred', () => {
    var _tooltip$find3;

    const tooltip = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Tooltip.Tooltip, defaultProps, children));
    (_tooltip$find3 = tooltip.find('button')) === null || _tooltip$find3 === void 0 ? void 0 : _tooltip$find3.trigger('onBlur');
    expect(tooltip).not.toContainReactComponent('p', {
      children: expect.arrayContaining([defaultProps.content])
    });
  });
  it('renders the tooltip content when the control is hovered', () => {
    var _tooltip$find4;

    const tooltip = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Tooltip.Tooltip, defaultProps, children));
    (_tooltip$find4 = tooltip.find('button')) === null || _tooltip$find4 === void 0 ? void 0 : _tooltip$find4.trigger('onMouseEnter');
    expect(tooltip).toContainReactComponent('p', {
      children: expect.arrayContaining([defaultProps.content])
    });
  });
  it('does not render the tooltip content when the control loses hover', () => {
    var _tooltip$find5;

    const tooltip = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Tooltip.Tooltip, defaultProps, children));
    (_tooltip$find5 = tooltip.find('button')) === null || _tooltip$find5 === void 0 ? void 0 : _tooltip$find5.trigger('onMouseLeave');
    expect(tooltip).not.toContainReactComponent('p', {
      children: expect.arrayContaining([defaultProps.content])
    });
  });
  it('toggles rendering the tooltip content when the control is clicked', () => {
    var _tooltip$find6, _tooltip$find7;

    const tooltip = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Tooltip.Tooltip, defaultProps, children));
    const fakeEvent = {
      preventDefault: jest.fn()
    };
    (_tooltip$find6 = tooltip.find('button')) === null || _tooltip$find6 === void 0 ? void 0 : _tooltip$find6.trigger('onClick', fakeEvent);
    expect(tooltip).toContainReactComponent('p', {
      children: expect.arrayContaining([defaultProps.content])
    });
    (_tooltip$find7 = tooltip.find('button')) === null || _tooltip$find7 === void 0 ? void 0 : _tooltip$find7.trigger('onClick', fakeEvent);
    tooltip.act(() => {
      jest.runAllTimers();
    });
    expect(tooltip).not.toContainReactComponent('p', {
      children: expect.arrayContaining([defaultProps.content])
    });
  });
  it('toggles rendering the tooltip content when RETURN is pressed on the control', () => {
    var _tooltip$find8, _tooltip$find9;

    const tooltip = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Tooltip.Tooltip, defaultProps, children));
    const fakeEvent = {
      preventDefault: jest.fn(),
      keyCode: _Tooltip.RETURN_KEY_CODE
    };
    (_tooltip$find8 = tooltip.find('button')) === null || _tooltip$find8 === void 0 ? void 0 : _tooltip$find8.trigger('onKeyDown', fakeEvent);
    expect(tooltip).toContainReactComponent('p', {
      children: expect.arrayContaining([defaultProps.content])
    });
    (_tooltip$find9 = tooltip.find('button')) === null || _tooltip$find9 === void 0 ? void 0 : _tooltip$find9.trigger('onKeyDown', fakeEvent);
    tooltip.act(() => {
      jest.runAllTimers();
    });
    expect(tooltip).not.toContainReactComponent('p', {
      children: expect.arrayContaining([defaultProps.content])
    });
  });
  it('toggles rendering the tooltip content when SPACE is pressed on the control', () => {
    var _tooltip$find10, _tooltip$find11;

    const tooltip = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Tooltip.Tooltip, defaultProps, children));
    const fakeEvent = {
      preventDefault: jest.fn(),
      keyCode: _Tooltip.SPACE_KEY_CODE
    };
    (_tooltip$find10 = tooltip.find('button')) === null || _tooltip$find10 === void 0 ? void 0 : _tooltip$find10.trigger('onKeyDown', fakeEvent);
    expect(tooltip).toContainReactComponent('p', {
      children: expect.arrayContaining([defaultProps.content])
    });
    (_tooltip$find11 = tooltip.find('button')) === null || _tooltip$find11 === void 0 ? void 0 : _tooltip$find11.trigger('onKeyDown', fakeEvent);
    tooltip.act(() => {
      jest.runAllTimers();
    });
    expect(tooltip).not.toContainReactComponent('p', {
      children: expect.arrayContaining([defaultProps.content])
    });
  });
  it('does not render the tooltip content when ESC is pressed on the control', () => {
    var _tooltip$find12;

    const tooltip = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Tooltip.Tooltip, defaultProps, children));
    const fakeEvent = {
      preventDefault: jest.fn(),
      keyCode: _Tooltip.ESCAPE_KEY_CODE
    };
    (_tooltip$find12 = tooltip.find('button')) === null || _tooltip$find12 === void 0 ? void 0 : _tooltip$find12.trigger('onKeyDown', fakeEvent);
    expect(tooltip).not.toContainReactComponent('p', {
      children: expect.arrayContaining([defaultProps.content])
    });
  });
  it('does not render the tooltip content when a key other than SPACE or RETURN is pressed on the control', () => {
    var _tooltip$find13;

    const tooltip = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Tooltip.Tooltip, defaultProps, children));
    const fakeEvent = {
      preventDefault: jest.fn(),
      keyCode: 10
    };
    (_tooltip$find13 = tooltip.find('button')) === null || _tooltip$find13 === void 0 ? void 0 : _tooltip$find13.trigger('onKeyDown', fakeEvent);
    expect(tooltip).not.toContainReactComponent('p', {
      children: expect.arrayContaining([defaultProps.content])
    });
  });
  it('renders a control button and tooltip with the required aria attributes when the tooltip is active', () => {
    var _tooltip$find14;

    const tooltip = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Tooltip.Tooltip, defaultProps, children));
    (_tooltip$find14 = tooltip.find('button')) === null || _tooltip$find14 === void 0 ? void 0 : _tooltip$find14.trigger('onFocus');
    const tooltipControl = tooltip.find('button');
    const tooltipContent = tooltip.findWhere(element => {
      return element.type === 'p' && element.text === defaultProps.content;
    });
    const tooltipContentId = (tooltipContent === null || tooltipContent === void 0 ? void 0 : tooltipContent.props).id;
    expect(tooltipContent).toHaveReactProps({
      role: 'tooltip'
    });
    expect(tooltipControl).toHaveReactProps({
      'aria-pressed': true,
      'aria-controls': tooltipContentId,
      'aria-describedby': tooltipContentId
    });
  });
  it('renders a control button with the required aria attributes when the tooltip is not active', () => {
    const tooltip = (0, _dom.mount)( /*#__PURE__*/_react.default.createElement(_Tooltip.Tooltip, defaultProps, children));
    expect(tooltip.find('button')).toHaveReactProps({
      'aria-pressed': false,
      'aria-controls': undefined,
      'aria-describedby': undefined
    });
  });
});