"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.computeOffsets = void 0;
function computeOffsets(placement, popperRect, referenceRect, { preventOverflow = false, sameWidth = false } = {}) {
    let offsets = { x: 0, y: 0 };
    let clipping = {};
    if (!popperRect || !referenceRect) {
        return { offsets, clipping };
    }
    const commonX = sameWidth
        ? referenceRect.left
        : referenceRect.left + referenceRect.width / 2 - popperRect.width / 2;
    switch (placement) {
        case 'top':
            offsets = {
                x: commonX,
                y: referenceRect.top - popperRect.height,
            };
            break;
        case 'bottom':
            offsets = {
                x: commonX,
                y: referenceRect.bottom,
            };
            break;
    }
    if (!sameWidth && preventOverflow) {
        clipping = getClipping(offsets, popperRect);
        if (clipping.right && !clipping.left) {
            offsets.x += clipping.right;
        }
        if (!clipping.right && clipping.left) {
            offsets.x = 0;
        }
    }
    return { offsets, clipping };
}
exports.computeOffsets = computeOffsets;
function getClipping(offsets, popperRect) {
    const viewportWidth = document.documentElement.clientWidth;
    const elementWidth = offsets.x + popperRect.width;
    let clipping = {};
    if (elementWidth > viewportWidth) {
        clipping = {
            right: viewportWidth - elementWidth,
        };
    }
    if (offsets.x < 0) {
        clipping = Object.assign(Object.assign({}, clipping), { left: -offsets.x });
    }
    return clipping;
}
