"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const test_utilities_1 = require("../../test-utilities");
const VisuallyHidden_1 = require("../VisuallyHidden");
const HiddenForAccessibility_1 = require("../HiddenForAccessibility");
const Radio_1 = require("./Radio");
const defaultProps = {
    name: 'radio_button',
    children: 'Save this information for next time',
};
describe('<Radio />', () => {
    it('renders an un-checked radio and label', () => {
        const radio = test_utilities_1.mountWithContext(<Radio_1.Radio {...defaultProps}/>);
        expect(radio).toContainReactComponent('input', {
            checked: false,
            type: 'radio',
        });
        expect(radio.find('label')).toContainReactText('Save this information for next time');
    });
    it('renders a checked radio when the checked prop is provided and set to true', () => {
        const radio = test_utilities_1.mountWithContext(<Radio_1.Radio {...defaultProps} checked/>);
        expect(radio).toContainReactComponent('input', {
            checked: true,
            type: 'radio',
        });
    });
    it('renders a checked radio when the value prop is provided and set to true', () => {
        const radio = test_utilities_1.mountWithContext(<Radio_1.Radio {...defaultProps} value/>);
        expect(radio).toContainReactComponent('input', {
            checked: true,
            type: 'radio',
        });
    });
    it('renders a disabled radio when the disabled prop is provided and set to true', () => {
        const radio = test_utilities_1.mountWithContext(<Radio_1.Radio {...defaultProps} disabled/>);
        expect(radio).toContainReactComponent('input', {
            disabled: true,
            type: 'radio',
        });
    });
    it('calls the onChange callback when the radio is checked and unchecked', () => {
        const onChangeSpy = jest.fn();
        const radio = test_utilities_1.mountWithContext(<Radio_1.Radio {...defaultProps} onChange={onChangeSpy}/>);
        radio.find('input').trigger('onChange', {
            currentTarget: { checked: true },
        });
        expect(onChangeSpy).toHaveBeenCalledWith(true);
        radio.find('input').trigger('onChange', {
            currentTarget: { checked: false },
        });
        expect(onChangeSpy).toHaveBeenCalledWith(false);
    });
    describe('accessibilityLabel', () => {
        it('renders visually hidden content when the accessibilityLabel is set', () => {
            const accessibilityLabelContent = 'Accessibility content';
            const radio = test_utilities_1.mountWithContext(<Radio_1.Radio {...defaultProps} accessibilityLabel={accessibilityLabelContent}/>);
            expect(radio.find(VisuallyHidden_1.VisuallyHidden)).toContainReactText(accessibilityLabelContent);
        });
        it('hides the label for accessibility purposes when the accessibilityLabel is set', () => {
            const children = 'Basic label';
            const radio = test_utilities_1.mountWithContext(<Radio_1.Radio {...defaultProps} accessibilityLabel="Accessibility content">
          {children}
        </Radio_1.Radio>);
            expect(radio.find(HiddenForAccessibility_1.HiddenForAccessibility)).toContainReactText(children);
        });
    });
});
