"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShellDisclosure = exports.ShellFooter = exports.ShellSectionContent = exports.ShellSection = exports.ShellHeading = exports.ShellSubheader = exports.ShellHeader = exports.Shell = void 0;
const react_1 = __importStar(require("react"));
const css_utilities_1 = require("@shopify/css-utilities");
const InlineStack_1 = require("../InlineStack");
const HeadingGroup_1 = require("../HeadingGroup");
const Icon_1 = require("../Icon");
const Text_1 = require("../Text");
const legacy_1 = require("../../utilities/legacy");
const transition_1 = require("../../utilities/transition");
const Shell_css_1 = __importDefault(require("./Shell.css"));
function Shell({ children, headerPosition, subheaderPosition, footerPosition, subheaderHidden, }) {
    return (<div className={css_utilities_1.classNames(Shell_css_1.default.Shell, headerPosition &&
        Shell_css_1.default[css_utilities_1.variationName('headerPosition', headerPosition)], subheaderPosition &&
        Shell_css_1.default[css_utilities_1.variationName('subheaderPosition', subheaderPosition)], footerPosition &&
        Shell_css_1.default[css_utilities_1.variationName('footerPosition', footerPosition)], subheaderHidden && Shell_css_1.default.subheaderHidden)}>
      {children}
    </div>);
}
exports.Shell = Shell;
function ShellHeader({ children, alignment, blockPadding, background, }) {
    const style = background
        ? {
            backgroundImage: `url(${JSON.stringify(background)})`,
        }
        : undefined;
    return (<HeadingGroup_1.HeadingGroup>
      <header role="banner" style={style} className={css_utilities_1.classNames(Shell_css_1.default.Header, Shell_css_1.default[css_utilities_1.variationName('Header-alignment', alignment)], Shell_css_1.default[css_utilities_1.variationName('Header-blockPadding', blockPadding)])}>
        <div className={Shell_css_1.default.HeaderInner}>{children}</div>
      </header>
    </HeadingGroup_1.HeadingGroup>);
}
exports.ShellHeader = ShellHeader;
function ShellSubheader({ children, alignment }) {
    return (<div className={css_utilities_1.classNames(Shell_css_1.default.Subheader, Shell_css_1.default[css_utilities_1.variationName('Subheader-alignment', alignment)])}>
      <div className={Shell_css_1.default.SubheaderInner}>{children}</div>
    </div>);
}
exports.ShellSubheader = ShellSubheader;
function ShellHeading({ to, logo, children }) {
    const content = (logo === null || logo === void 0 ? void 0 : logo.source) ? (<img src={logo.source} alt={children} 
    // TODO: convert to rems
    style={logo.maxWidth ? { maxWidth: logo.maxWidth } : undefined} className={Shell_css_1.default.Logo}/>) : (children);
    return to ? (<a className={Shell_css_1.default.Heading} href={to}>
      {content}
    </a>) : (<span className={Shell_css_1.default.Heading}>{content}</span>);
}
exports.ShellHeading = ShellHeading;
function ShellSection({ bordered, background, inlineSize, blockSize, children, secondary, }) {
    const Element = secondary ? 'aside' : 'div';
    return (<HeadingGroup_1.HeadingGroup>
      <Element className={css_utilities_1.classNames(Shell_css_1.default.Section, bordered && Shell_css_1.default['Section-bordered'], background && backgroundToLegacyClassName(background), background && Shell_css_1.default[css_utilities_1.variationName('Section-background', background)], inlineSize && Shell_css_1.default[css_utilities_1.variationName('Section-inlineSize', inlineSize)], blockSize && Shell_css_1.default[css_utilities_1.variationName('Section-blockSize', blockSize)], secondary && Shell_css_1.default['Section-secondary'])}>
        <div className={Shell_css_1.default.SectionInner}>{children}</div>
      </Element>
    </HeadingGroup_1.HeadingGroup>);
}
exports.ShellSection = ShellSection;
function ShellSectionContent({ children }) {
    return (<div className={Shell_css_1.default.SectionContent}>
      <div className={Shell_css_1.default.SectionContentInner}>{children}</div>
    </div>);
}
exports.ShellSectionContent = ShellSectionContent;
function ShellFooter({ children }) {
    return (<HeadingGroup_1.HeadingGroup>
      <footer role="contentinfo" className={Shell_css_1.default.Footer}>
        <div className={Shell_css_1.default.FooterInner}>{children}</div>
      </footer>
    </HeadingGroup_1.HeadingGroup>);
}
exports.ShellFooter = ShellFooter;
// TODO: a11y
function ShellDisclosure({ children, detail, labels, icon, bordered, background, }) {
    const [open, setOpen] = react_1.useState(false);
    const disclosureRef = react_1.useRef(null);
    const transition = transition_1.useTransition(open, 'slow');
    const transitionStyles = {
        enter: () => ({ height: 0 }),
        entering: () => { var _a; return ({ height: (_a = disclosureRef === null || disclosureRef === void 0 ? void 0 : disclosureRef.current) === null || _a === void 0 ? void 0 : _a.clientHeight }); },
        entered: () => ({ height: 'auto' }),
        exit: () => { var _a; return ({ height: (_a = disclosureRef === null || disclosureRef === void 0 ? void 0 : disclosureRef.current) === null || _a === void 0 ? void 0 : _a.clientHeight }); },
        exiting: () => ({ height: 0 }),
    };
    const { text, icon: disclosureIcon } = open
        ? {
            text: labels.closed,
            icon: <Icon_1.Icon source="chevronUp" size="small" color="interactive"/>,
        }
        : {
            text: labels.open,
            icon: <Icon_1.Icon source="chevronDown" size="small" color="interactive"/>,
        };
    const contentId = 'disclosure_content';
    return (<aside className={css_utilities_1.classNames(Shell_css_1.default.Disclosure, bordered && Shell_css_1.default['Disclosure-bordered'], background && backgroundToLegacyClassName(background), background &&
        Shell_css_1.default[css_utilities_1.variationName('Disclosure-background', background)])}>
      <button type="button" className={css_utilities_1.classNames(Shell_css_1.default.DisclosureButton, legacy_1.utilityDefaultBorderColor)} onClick={() => setOpen((open) => !open)} aria-pressed={open} aria-controls={contentId} aria-expanded={open}>
        <span className={Shell_css_1.default.DisclosureLayout}>
          <InlineStack_1.InlineStack spacing="tight" alignment="center">
            <Icon_1.Icon source={icon} size="large" color="interactive"/>
            <Text_1.Text>{text}</Text_1.Text>
            {disclosureIcon}
          </InlineStack_1.InlineStack>
          {detail}
        </span>
      </button>
      {transition !== 'exited' && (<div className={css_utilities_1.classNames(Shell_css_1.default.DisclosureContent, legacy_1.utilityDefaultBorderColor)} style={Object.assign({}, transitionStyles[transition]())} id={contentId}>
          <div className={Shell_css_1.default.DisclosureContentInner} ref={disclosureRef}>
            {children}
          </div>
        </div>)}
    </aside>);
}
exports.ShellDisclosure = ShellDisclosure;
function backgroundToLegacyClassName(background) {
    switch (background) {
        case 'surfacePrimary':
            return legacy_1.colorSurfacePrimary;
        case 'surfaceSecondary':
            return legacy_1.colorSurfaceSecondary;
        case 'surfaceTertiary':
            return legacy_1.colorSurfaceTertiary;
    }
}
