"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const dom_1 = require("@quilted/react-testing/dom");
const faker_1 = __importDefault(require("faker"));
const _1 = require(".");
const defaultProps = {
    source: faker_1.default.internet.url(),
    description: faker_1.default.lorem.words(2),
};
describe('Thumbnail', () => {
    it('renders an <img /> with an src and an alt attributes', () => {
        const thumbnail = dom_1.mount(<_1.Thumbnail {...defaultProps} badge="1"/>);
        expect(thumbnail).toContainReactComponent('img', {
            src: defaultProps.source,
            alt: defaultProps.description,
        });
    });
    it('renders a badge when provided as a string', () => {
        const thumbnail = dom_1.mount(<_1.Thumbnail {...defaultProps} badge="1"/>);
        expect(thumbnail.find('span')).toContainReactText('1');
    });
    it('renders a badge when provided as a number', () => {
        const thumbnail = dom_1.mount(<_1.Thumbnail {...defaultProps} badge={0}/>);
        expect(thumbnail.find('span')).toContainReactText('0');
    });
    it("doesn't render a badge when not provided", () => {
        const thumbnail = dom_1.mount(<_1.Thumbnail {...defaultProps}/>);
        expect(thumbnail).not.toContainReactComponent('span');
    });
});
